from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .access_date import IssueTitle
from .issue_subtitle import IssueSubtitle
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue
from .trans_title_group import TransTitleGroup


@dataclass
class IssueTitleGroup:
    """
    <div> <h3>Issue Title Group</h3> </div>
    """
    class Meta:
        name = "issue-title-group"

    issue_title: Optional[IssueTitle] = field(
        default=None,
        metadata={
            "name": "issue-title",
            "type": "Element",
            "required": True,
        }
    )
    issue_subtitle: List[IssueSubtitle] = field(
        default_factory=list,
        metadata={
            "name": "issue-subtitle",
            "type": "Element",
        }
    )
    trans_title_group: List[TransTitleGroup] = field(
        default_factory=list,
        metadata={
            "name": "trans-title-group",
            "type": "Element",
        }
    )
    content_type: Optional[str] = field(
        default=None,
        metadata={
            "name": "content-type",
            "type": "Attribute",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional


@dataclass
class NameOfSubstance:
    ui: Optional[str] = field(
        default=None,
        metadata={
            "name": "UI",
            "type": "Attribute",
            "required": True,
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import List, Optional, Union
from .contributed_resource_group import ContributedResourceGroup
from .funding_group import FundingGroup
from .org.w3.xml.pkg_1998.namespace.lang_value import LangValue


@dataclass
class SupportGroup:
    """
    <div> <h3>Support Group</h3> </div>
    """
    class Meta:
        name = "support-group"

    funding_group: List[FundingGroup] = field(
        default_factory=list,
        metadata={
            "name": "funding-group",
            "type": "Element",
        }
    )
    contributed_resource_group: List[ContributedResourceGroup] = field(
        default_factory=list,
        metadata={
            "name": "contributed-resource-group",
            "type": "Element",
        }
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    specific_use: Optional[str] = field(
        default=None,
        metadata={
            "name": "specific-use",
            "type": "Attribute",
        }
    )
    base: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )
    lang: Optional[Union[str, LangValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "namespace": "http://www.w3.org/XML/1998/namespace",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Dict, List, Optional, Union
from .malignmark_edge import MalignmarkEdge
from .malignmark_value import MalignmarkValue

__NAMESPACE__ = "http://www.w3.org/1998/Math/MathML"


@dataclass
class Malignmark:
    class Meta:
        name = "malignmark"
        namespace = "http://www.w3.org/1998/Math/MathML"

    id: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    xref: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    class_value: List[str] = field(
        default_factory=list,
        metadata={
            "name": "class",
            "type": "Attribute",
            "tokens": True,
        }
    )
    style: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    href: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other: Optional[object] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )
    other_attributes: Dict[str, str] = field(
        default_factory=dict,
        metadata={
            "type": "Attributes",
            "namespace": "##other",
        }
    )
    mathcolor: Optional[str] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    mathbackground: Optional[Union[str, MalignmarkValue]] = field(
        default=None,
        metadata={
            "type": "Attribute",
            "pattern": r"\s*((#[0-9a-fA-F]{3}([0-9a-fA-F]{3})?)|[aA][qQ][uU][aA]|[bB][lL][aA][cC][kK]|[bB][lL][uU][eE]|[fF][uU][cC][hH][sS][iI][aA]|[gG][rR][aA][yY]|[gG][rR][eE][eE][nN]|[lL][iI][mM][eE]|[mM][aA][rR][oO][oO][nN]|[nN][aA][vV][yY]|[oO][lL][iI][vV][eE]|[pP][uU][rR][pP][lL][eE]|[rR][eE][dD]|[sS][iI][lL][vV][eE][rR]|[tT][eE][aA][lL]|[wW][hH][iI][tT][eE]|[yY][eE][lL][lL][oO][wW])\s*",
        }
    )
    edge: Optional[MalignmarkEdge] = field(
        default=None,
        metadata={
            "type": "Attribute",
        }
    )



from dataclasses import field
from pydantic.dataclasses import dataclass
from typing import Optional
from .descriptor_name_major_topic_yn import DescriptorNameMajorTopicYn
from .descriptor_name_type import DescriptorNameType


@dataclass
class DescriptorName:
    major_topic_yn: DescriptorNameMajorTopicYn = field(
        default=DescriptorNameMajorTopicYn.N,
        metadata={
            "name": "MajorTopicYN",
            "type": "Attribute",
            "required": True,
        }
    )
    ui: Optional[str] = field(
        default=None,
        metadata={
            "name": "UI",
            "type": "Attribute",
            "required": True,
        }
    )
    type: Optional[DescriptorNameType] = field(
        default=None,
        metadata={
            "name": "Type",
            "type": "Attribute",
        }
    )
    value: str = field(
        default="",
        metadata={
            "required": True,
        }
    )
